@@ -1,4 +1,5 @@
 import hashlib
+import json
 import logging
 import os
 import sys
@@ -285,9 +286,15 @@ def process_member_sample(samples, sample_path, verbose=False) -> dict:
                     else:
                         preserved_json[key] = "unpreserved"
 
+                new_annotation = {}
+
+                for key, value in preserved_json.items():
+                    new_key = normalize_json_key(key)
+                    new_annotation[new_key] = value
+
                 push_json_to_s3(
                     s3=s3,
-                    json_obj=preserved_json,
+                    json_obj=new_annotation,
                     bucket=ANNOTATION_BUCKET,
                     path=aws_key,
                 )
@@ -412,7 +419,8 @@ def push_json_to_s3(
 
     if verbose:
         logging.info("Normalizing JSON keys")
-        json_obj = normalize_json_keys(json_obj)
+
+    json_obj = normalize_json_keys(json_obj)
 
     if verbose:
         logging.info(f"Writing JSON to S3 bucket {bucket} at path {path}")
@@ -427,10 +435,12 @@ def normalize_json_keys(json_obj: dict) -> dict:
     :param json_obj: the JSON object to normalize
     :return: a new JSON object with normalized keys
     """
-    for key in json_obj:
-        json_obj[normalize_json_key(key)] = json_obj.pop(key)
+    new_json_obj = {}
 
-    return json_obj
+    for key in json_obj:
+        new_json_obj[normalize_json_key(key)] = json_obj[key]
+
+    return new_json_obj
 
 
 def normalize_json_key(key: str) -> str:
@@ -501,6 +511,7 @@ def process_sample(
         json_obj=overall_status,
         bucket=annotation_bucket,
         path=key,
+        verbose=True,
     )
 
     return {member_id: overall_status}
@@ -551,6 +562,98 @@ def generate_report(resume_from: int):
     return members
 
 
+def member_reports():
+    s3client = boto3.client("s3")
+    session = boto3.Session()
+    s3 = session.resource("s3")
+
+    # get member list from S3
+    members = get_members(
+        s3client=s3client,
+        samples_bucket=SAMPLES_BUCKET,
+        samples_path=SAMPLES_PATH,
+    )
+
+    from joblib import Parallel, delayed
+    from rich.progress import track
+
+    results = Parallel(n_jobs=PARALLEL_JOBS)(
+        delayed(member_report)(
+            member_id,
+        )
+        for member_id in track(members)
+    )
+
+
+def member_report(member_id):
+    import boto3
+    import logging
+
+    s3client = boto3.client("s3")
+    session = boto3.Session()
+    s3 = session.resource("s3")
+
+    samples = get_samples(
+        s3client=s3client,
+        member_id=member_id,
+        samples_bucket=SAMPLES_BUCKET,
+        samples_path=SAMPLES_PATH,
+    )
+
+    overall_samples = []
+    unpreserved_samples = []
+
+    import botocore
+
+    for sample in samples:
+        sample = json.loads(sample)["data-point"]
+
+        if "type" in sample and sample["type"] == "journal-article":
+            print(f"Appending {sample['DOI']}")
+
+            md5_doi = hashlib.md5(sample["DOI"].lower().encode()).hexdigest()
+
+            try:
+                annotation = get_annotation(
+                    s3client=s3client,
+                    member_id=member_id,
+                    annotation_name="preservation.json",
+                    annotations_bucket=ANNOTATION_BUCKET,
+                    annotations_path=ANNOTATION_PATH,
+                    path=f"works/{md5_doi}",
+                    use_member_id=False,
+                )
+
+                preserved = any(
+                    v.startswith("preserved")
+                    for v in annotation.values()
+                    if isinstance(v, str)
+                )
+
+                if not preserved:
+                    unpreserved_samples.append(annotation)
+
+                overall_samples.append(annotation)
+
+            except Exception as e:
+                print(e)
+                print(f"This DOI was excluded: {sample['DOI']}")
+
+    key = f"{REPORT_PATH}/members/{member_id}/preservation-report.json"
+    unpreserved_key = f"{REPORT_PATH}/members/{member_id}/unpreserved.json"
+
+    push_json_to_s3(
+        s3=s3,
+        json_obj=unpreserved_samples,
+        bucket=REPORT_BUCKET,
+        path=unpreserved_key,
+    )
+
+    push_json_to_s3(
+        s3=s3, json_obj=overall_samples, bucket=REPORT_BUCKET, path=key
+    )
+
+
 def rescore_member(
     annotation_bucket,
     annotation_filename,
@@ -619,64 +722,6 @@ def rescore_member(
         raise e
 
 
-def count_a():
-    import boto3
-    import logging
-
-    s3client = boto3.client("s3")
-    session = boto3.Session()
-    s3 = session.resource("s3")
-
-    # get member list from S3
-    members = get_members(
-        s3client=s3client,
-        samples_bucket=SAMPLES_BUCKET,
-        samples_path=SAMPLES_PATH,
-    )
-
-    plus_token = os.environ.get("CROSSREF_PLUS_TOKEN", None)
-
-    from crossref.restful import Etiquette, Members
-
-    my_etiquette = Etiquette(
-        "Preservation Status",
-        "0.01",
-        "https://eve.gd",
-        "meve@crossref.org",
-    )
-
-    a_count = 0
-
-    for member in members:
-        logging.info(f"Fetching preservation statistics for member {member}")
-
-        if plus_token:
-            members = Members(
-                etiquette=my_etiquette,
-                crossref_plus_token=plus_token,
-            )
-            logging.info(f"Using plus lookup")
-        else:
-            members = Members(etiquette=my_etiquette)
-            logging.info(f"Using regular lookup")
-
-        logging.info(f"API lookup for {member}: done")
-
-        member_obj = members.member(member)
-
-        if "primary-name" not in member_obj:
-            print(member_obj)
-
-        country = member_obj["location"].split(",")[-1]
-        if country == "Argentina":
-            a_count += 1
-
-            if a_count > 1:
-                return a_count
-
-    return a_count
-
-
 def overall_report(members=None, limit=0):
     import boto3
     import logging
@@ -1074,12 +1119,21 @@ def rescore_all(members=None, limit=0):
 
 
 def get_annotation(
-    s3client, member_id, annotations_bucket, annotations_path, annotation_name
+    s3client,
+    member_id,
+    annotations_bucket,
+    annotations_path,
+    annotation_name,
+    path="members",
+    use_member_id=True,
 ):
     if s3client is None:
         s3client = boto3.client("s3")
 
-    key = f"{annotations_path}/members/{member_id}/{annotation_name}"
+    if use_member_id:
+        key = f"{annotations_path}/{path}/{member_id}/{annotation_name}"
+    else:
+        key = f"{annotations_path}/{path}/{annotation_name}"
 
     data = (
         s3client.get_object(Bucket=annotations_bucket, Key=key)["Body"]
